==> aws-solutions-constructs.aws-dynamodbstreams-lambda-elasticsearch-kibana-2.0.0rc2.tar.gz: aws-solutions-constructs.aws-dynamodbstreams-lambda-elasticsearch-kibana-2.0.0rc2/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-dynamodbstreams-lambda-elasticsearch-kibana",
    "version": "2.0.0.rc2",
    "description": "CDK Constructs for Amazon Dynamodb streams to AWS Lambda to AWS Elasticsearch with Kibana integration",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana",
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana._jsii": [
            "aws-dynamodbstreams-lambda-elasticsearch-kibana@2.0.0-rc.2.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk-lib>=2.0.0.rc23, <3.0.0",
        "aws-solutions-constructs.aws-dynamodbstreams-lambda==2.0.0.rc2",
        "aws-solutions-constructs.aws-lambda-elasticsearch-kibana==2.0.0.rc2",
        "aws-solutions-constructs.core==2.0.0.rc2",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.41.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-constructs.aws-dynamodbstreams-lambda-elasticsearch-kibana-2.1.0.tar.gz: aws-solutions-constructs.aws-dynamodbstreams-lambda-elasticsearch-kibana-2.1.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-dynamodbstreams-lambda-elasticsearch-kibana",
    "version": "2.1.0",
    "description": "CDK Constructs for Amazon Dynamodb streams to AWS Lambda to AWS Elasticsearch with Kibana integration",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana",
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana._jsii": [
            "aws-dynamodbstreams-lambda-elasticsearch-kibana@2.1.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk-lib>=2.4.0, <3.0.0",
        "aws-solutions-constructs.aws-dynamodbstreams-lambda==2.1.0",
        "aws-solutions-constructs.aws-lambda-elasticsearch-kibana==2.1.0",
        "aws-solutions-constructs.core==2.1.0",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.52.1, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
